@@ -2,8 +2,10 @@ window.localisation.kr = {
   confirm: '확인',
   server: '서버',
   theme: '테마',
+  site_customisation: '사이트 사용자 정의',
   funding: '자금',
   users: '사용자',
+  audit: '감사',
   apps: '앱',
   channels: '채널',
   transactions: '거래 내역',
@@ -26,24 +28,25 @@ window.localisation.kr = {
   restart: '서버 재시작',
   save: '저장',
   save_tooltip: '변경 사항 저장',
-  topup: '자금 추가',
-  topup_wallet: '지갑에 자금 추가',
-  topup_hint: '자금을 추가할 지갑의 ID를 넣어주세요',
+  credit_debit: '크레딧 / 직불카드',
+  credit_hint: '계정에 자금을 넣으려면 Enter를 눌러주세요',
+  credit_label: '{denomination} 단위로 충전하기',
+  credit_ok:
+    '가상 자금({amount} sats) 입출금 성공. 지불은 자금 출처의 실제 자금에 따라 달라집니다.',
   restart_tooltip: '변경 사항을 적용하려면 서버를 재시작해야 합니다.',
   add_funds_tooltip: '지갑에 자금을 추가합니다.',
   reset_defaults: '기본 설정으로 돌아가기',
   reset_defaults_tooltip:
     '설정했던 내용들을 모두 지우고, 기본 설정으로 돌아갑니다.',
   download_backup: '데이터베이스 백업 다운로드',
-  name_your_wallet: '사용할 %{name}지갑의 이름을 정하세요',
-  wallet_topup_ok:
-    '성공적으로 가상 자금을 생성했습니다 (%{amount} sats). 지급은 자금 원천의 실제 자금에 따라 달라집니다.',
+  name_your_wallet: '사용할 {name}지갑의 이름을 정하세요',
   paste_invoice_label: '인보이스, 결제 요청, 혹은 lnurl 코드를 붙여넣으세요 *',
   lnbits_description:
     '설정이 쉽고 가벼운 LNbits는 어떤 라이트닝 네트워크의 예산 자원 위에서든 돌아갈 수 있습니다, 그리고 다른 LNbits 지갑들입니다. 스스로 사용하기 위해, 또는 다른 사람들에게 수탁형 솔루션을 제공하기 위해 LNbits를 운영할 수 있습니다. 각 지갑들은 자신만의 API key를 가지며, 생성 가능한 지갑의 수에는 제한이 없습니다. 자금을 분할할 수 있는 기능으로 인해, LNbits는 자금 운영 도구로써뿐만 아니라 개발 도구로써도 유용합니다. 확장 기능들은 LNbits에 여러분들이 라이트닝 네트워크의 다양한 최신 기술들을 수행해볼 수 있게 하는 추가 기능을 제공합니다. LNbits 개발진들은 확장 기능들의 개발 또한 가능한 쉽게 만들었으며, 무료 오픈 소스 프로젝트답게 사람들이 자신만의 확장 기능들을 개발하고 제출하기를 응원합니다.',
   export_to_phone: 'QR 코드를 이용해 모바일 기기로 내보내기',
   export_to_phone_desc:
     '이 QR 코드는 선택된 지갑의 최대 접근 권한을 가진 전체 URL을 담고 있습니다. 스캔 후, 모바일 기기에서 지갑을 열 수 있습니다.',
+  wallet: '지갑:',
   wallets: '지갑',
   add_wallet: '새로운 지갑을 추가합니다',
   delete_wallet: '지갑을 삭제합니다',
@@ -58,9 +61,9 @@ window.localisation.kr = {
   donate: '기부',
   view_github: 'GitHub 페이지 보기',
   voidwallet_active: 'VoidWallet이 활성화되었습니다! 결제가 불가능합니다.',
-  use_with_caution: '주의하세요 - %{name} 지갑은 아직 BETA 단계입니다.',
-  service_fee: '서비스 수수료: 거래액의 %{amount} %',
-  service_fee_max: '서비스 수수료: 거래액의 %{amount} % (최대 %{max} sats)',
+  use_with_caution: '주의하세요 - {name} 지갑은 아직 BETA 단계입니다.',
+  service_fee: '서비스 수수료: 거래액의 {amount} %',
+  service_fee_max: '서비스 수수료: 거래액의 {amount} % (최대 {max} sats)',
   service_fee_tooltip:
     '지불 결제 시마다 LNbits 서버 관리자에게 납부되는 서비스 수수료',
   toggle_darkmode: '다크 모드 전환',
@@ -70,8 +73,6 @@ window.localisation.kr = {
   api_keys_api_docs: '노드 URL, API 키와 API 문서',
   lnbits_version: 'LNbits 버전',
   runs_on: 'Runs on',
-  credit_hint: '계정에 자금을 넣으려면 Enter를 눌러주세요',
-  credit_label: '%{denomination} 단위로 충전하기',
   paste: '붙여넣기',
   paste_from_clipboard: '클립보드에서 붙여넣기',
   paste_request: '지불 요청 붙여넣기',
@@ -88,7 +89,7 @@ window.localisation.kr = {
   pay: '지불하기',
   memo: 'Memo',
   date: '일시',
-  processing_payment: '결제 처리 중...',
+  payment_processing: '결제 처리 중...',
   not_enough_funds: '자금이 부족합니다!',
   search_by_tag_memo_amount: '태그, memo, 수량으로 검색하기',
   invoice_waiting: '결제를 기다리는 인보이스',
@@ -107,10 +108,15 @@ window.localisation.kr = {
     '로그인 기능은 향후 업데이트를 통해 지원될 계획이지만, 현재로써는 이 페이지에 향후 다시 접속하기 위해 북마크 설정하는 것을 잊지 마세요! 이 서비스는 아직 BETA 과정에 있고, LNbits 개발자들은 자금 손실에 대해 전혀 책임을 지지 않습니다.',
   no_transactions: '아직 아무런 거래도 이루어지지 않았습니다',
   manage: '관리',
+  exchanges: '거래소',
   extensions: '확장 기능',
   no_extensions: '아직 설치된 확장 기능들이 없네요 :(',
   created: '생성됨',
   search_extensions: '확장 기능 검색하기',
+  extension_sources: '확장 소스',
+  ext_sources_hint: '확장 프로그램을 다운로드할 수 있는 저장소',
+  ext_sources_label:
+    '출처 URL (공식 LNbits 확장 소스만 사용하고, 신뢰할 수 있는 출처를 사용하세요)',
   warning: '주의',
   repository: '저장소',
   confirm_continue: '정말로 계속할까요?',
@@ -119,8 +125,10 @@ window.localisation.kr = {
   uninstall: '삭제',
   drop_db: '데이터 삭제',
   enable: '활성화',
+  pay_to_enable: '지불하여 활성화',
   enable_extension_details: '현재 사용자 계정에 해당 확장 기능을 활성화합니다',
   disable: '비활성화',
+  delete: '삭제',
   installed: '설치됨',
   activated: '작동됨',
   deactivated: '작동 중지',
@@ -142,31 +150,29 @@ window.localisation.kr = {
     '해당 확장 기능의 모든 데이터가 영구적으로 삭제됩니다. 작업 수행 후에는 되돌릴 수 없습니다!',
   extension_db_drop_warning:
     '해당 확장 기능의 모든 데이터가 영구적으로 삭제될 겁니다. 계속하려면 확장 기능의 이름을 입력해주세요:',
-  extension_min_lnbits_version:
+  extension_required_lnbits_version:
     '이 배포 버전은 더 높은 버전의 lnbits가 설치되어 있어야 합니다.',
+  min_version: '최소값 (포함됨)',
+  max_version: '최대값 (제외됨)',
   payment_hash: '결제 해쉬값',
   fee: '수수료',
   amount: '액수',
+  amount_sats: '금액 (사토시)',
   tag: '태그',
   unit: '단위',
   description: '상세',
   expiry: '만료',
   webhook: 'Webhook',
   payment_proof: 'Payment 증거',
-  update_available: '%{version}으로 업데이트가 가능합니다.',
-  latest_update: '이미 %{version} 버전으로 업데이트되었습니다.',
+  update: '업데이트',
+  update_available: '{version}으로 업데이트가 가능합니다.',
+  latest_update: '이미 {version} 버전으로 업데이트되었습니다.',
   notifications: '알림',
   no_notifications: '알림 없음',
   notifications_disabled: 'LNbits 상태 알림이 비활성화되었습니다.',
   enable_notifications: '알림 활성화',
   enable_notifications_desc:
     '활성화 시, 가장 최신의 보안 사고나 소프트웨어 업데이트 등의 LNbits 상황 업데이트를 불러옵니다.',
-  enable_killswitch: '비상 정지 활성화',
-  enable_killswitch_desc:
-    '활성화 시, LNbits 메인 서버에서 비상 정지 신호를 보내면 자동으로 자금의 원천을 VoidWallet으로 변경합니다. 업데이트 이후 수동으로 활성화해 주어야 합니다.',
-  killswitch_interval: '비상 정지 시간 간격',
-  killswitch_interval_desc:
-    'LNbits 메인 서버에서 나오는 비상 정지 신호를 백그라운드 작업으로 얼마나 자주 확인할 것인지를 결정합니다. (분 단위)',
   enable_watchdog: '와치독 활성화',
   enable_watchdog_desc:
     '활성화 시, LNbits 잔금보다 당신의 잔금이 지정한 수준보다 더 낮아질 경우 자동으로 자금의 원천을 VoidWallet으로 변경합니다. 업데이트 이후 수동으로 활성화해 주어야 합니다.',
@@ -183,7 +189,6 @@ window.localisation.kr = {
   more: '더 알아보기',
   less: '적게',
   releases: '배포 버전들',
-  killswitch: '비상 정지',
   watchdog: '와치독',
   server_logs: '서버 로그',
   ip_blocker: 'IP 기반 차단기',
@@ -214,6 +219,7 @@ window.localisation.kr = {
   login_to_account: '계정에 로그인하세요.',
   create_account: '계정 생성',
   account_settings: '계정 설정',
+  signin_with_nostr: 'Nostr로 계속하기',
   signin_with_google: 'Google으로 로그인',
   signin_with_github: 'GitHub으로 로그인',
   signin_with_keycloak: 'Keycloak으로 로그인',
@@ -222,11 +228,14 @@ window.localisation.kr = {
   password_config: '비밀번호 설정',
   password_repeat: '비밀번호 재입력',
   change_password: '비밀번호 변경',
+  update_credentials: '자격 증명 업데이트',
+  update_pubkey: '공개 키 업데이트',
   set_password: '비밀번호 설정',
   invalid_password: '비밀번호는 최소 8자 이상이어야 합니다',
   login: '로그인',
   register: '등록',
   username: '사용자 이름',
+  pubkey: '공개 키',
   user_id: '사용자 ID',
   email: '이메일',
   first_name: '성명',
@@ -241,14 +250,180 @@ window.localisation.kr = {
   back: '뒤로',
   logout: '로그아웃',
   look_and_feel: '외관과 느낌',
+  toggle_gradient: '그라디언트 전환',
+  gradient_background: '그라디언트 배경',
   language: '언어',
   color_scheme: '색상 구성',
-  extension_cost: '이 버전은 최소 %{cost} sats의 지불이 필요합니다.',
-  extension_paid_sats: '당신은 이미 %{paid_sats} sats를 지불했습니다.',
+  admin_settings: '관리자 설정',
+  extension_cost: '이 버전은 최소 {cost} sats의 지불이 필요합니다.',
+  extension_paid_sats: '당신은 이미 {paid_sats} sats를 지불했습니다.',
   release_details_error: '릴리스 세부 정보를 가져올 수 없습니다.',
   pay_from_wallet: '지갑에서 결제하다',
+  wallet_required: '지갑 *',
   show_qr: 'QR 보기',
   retry_install: '다시 설치하세요',
   new_payment: '새로운 결제하기',
-  hide_empty_wallets: '빈 지갑 숨기기'
+  update_payment: '결제 업데이트',
+  already_paid_question: '이미 지불하셨나요?',
+  sell: '판매',
+  sell_require: '확장을 활성화하려면 결제를 요청하십시오.',
+  sell_info:
+    '{name} 확장 기능을 활성화하려면 최소 {amount} 사토시의 결제가 필요합니다.',
+  hide_empty_wallets: '빈 지갑 숨기기',
+  recheck: '재확인',
+  contributors: '기여자',
+  license: '라이선스',
+  reset_key: '재설정 키',
+  reset_password: '비밀번호 재설정',
+  border_choices: '테두리 선택사항',
+  select_all: '모두 선택',
+  nfc_supported: 'NFC 지원됨',
+  nfc_not_supported: 'NFC 지원되지 않음',
+  expire_date: '만료 날짜:',
+  hash: '해시:',
+  welcome_lnbits: 'LNbits에 오신 것을 환영합니다.',
+  setup_su_account: '슈퍼유저 계정을 아래에 설정하십시오.',
+  create_ticker_converter: '통화 티커 변환기 생성',
+  enable_audit: '감사 활성화',
+  recommended: '추천됨',
+  audit_desc: '지정된 필터에 따라 HTTP 요청 기록',
+  audit_record_req: '레코드 요청 본문',
+  audit_record_warning: '경고:',
+  audit_record_req_warning_1: '암호와 같은 기밀 데이터가 기록됩니다.',
+  audit_record_req_warning_2: '요청 본문은 큰 크기를 가질 수 있습니다.',
+  audit_record_use: '주의해서 사용하십시오.',
+  audit_ip: 'IP 주소 기록',
+  audit_ip_desc: '클라이언트의 IP 주소를 기록하십시오.',
+  audit_path_params: '경로 매개변수 기록',
+  audit_query_params: '쿼리 매개변수 기록',
+  audit_http_methods: 'HTTP 메서드 포함',
+  audit_http_methods_hint:
+    '포함할 HTTP 메서드 목록. 목록이 비어 있으면 모두 포함됩니다.',
+  audit_http_methods_label: 'HTTP 방법',
+  audit_resp_codes: 'HTTP 응답 코드 포함',
+  audit_resp_codes_hint:
+    '포함할 HTTP 코드 목록(정규 표현식 일치). 빈 목록은 모두를 의미합니다. 예: 4.*, 5.*',
+  audit_resp_codes_label: 'HTTP 응답 코드 (정규식)',
+  audit_paths: '포함 경로',
+  audit_paths_hint:
+    '포함할 경로 목록 (정규 표현식 일치). 빈 목록은 모두를 의미합니다.',
+  audit_paths_label: 'HTTP 경로 (정규식)',
+  audit_paths_exclude: '제외 경로',
+  audit_paths_exclude_hint:
+    '제외할 경로 목록 (정규 표현식 일치). 빈 목록은 없음을 의미합니다.',
+  audit_paths_exclude_label: 'HTTP 경로 (정규식)',
+  exchange_providers: '거래소 공급자',
+  admin_extensions: '관리자 확장 프로그램',
+  admin_extensions_label: '관리자 확장 기능',
+  admin_extensions_hint:
+    '확장 기능은 관리자 권한이 있는 사용자만 사용할 수 있습니다.',
+  user_default_extensions: '사용자 기본 확장자',
+  user_default_extensions_label: '사용자 확장 기능',
+  user_default_extensions_hint: '사용자에게 기본적으로 활성화될 확장 기능.',
+  miscellanous: '기타',
+  misc_disable_extensions: '확장 프로그램 사용 안 함',
+  misc_disable_extensions_label: '모든 확장 프로그램 비활성화',
+  misc_hide_api: 'API 숨기기',
+  misc_hide_api_label: '지갑 API 숨기기, 확장 기능은 준수할 수 있음',
+  wallets_management: '지갑 관리',
+  funding_source_info: '자금 출처 정보',
+  funding_source: '자금 출처: {wallet_class}',
+  node_balance: '노드 잔액: {balance} 사토시',
+  lnbits_balance: 'LNbits 잔액: {balance} sats',
+  funding_reserve_percent: '예약 비율: {percent} %',
+  node_management: '노드 관리',
+  node_management_not_supported:
+    '활성화된 자금 출처에 의해 노드 관리는 지원되지 않습니다.',
+  toggle_node_ui: '노드 UI',
+  toggle_public_node_ui: '공개 노드 UI',
+  toggle_transactions_node_ui: '트랜잭션 탭 (대형 CLN 노드에서는 비활성화)',
+  invoice_expiry: '송장 만료',
+  invoice_expiry_label: '송장 만료 (초)',
+  fee_reserve: '수수료 예약',
+  fee_reserve_msats: 'msats의 예약 수수료',
+  fee_reserve_percent: '예약 수수료(%)',
+  server_management: '서버 관리',
+  base_url: '기본 URL',
+  base_url_label: '서버의 정적/기본 URL',
+  authentication: '인증',
+  auth_token_expiry_label: '토큰 만료 시간(분)',
+  auth_token_expiry_hint: '토큰이 만료되기까지 남은 시간(분)',
+  auth_allowed_methods_label: '허용된 인증 방법',
+  auth_allowed_methods_hint: '인증 방법 선택',
+  auth_nostr_label: 'Nostr 요청 URL',
+  auth_nostr_hint: '클라이언트가 로그인하는 데 사용할 절대 URL.',
+  auth_google_ci_label: 'Google 클라이언트 ID',
+  auth_google_ci_hint:
+    '허가된 리디렉션 URI에 https://{domain}/api/v1/auth/google/token이 포함되어 있는지 확인하세요.',
+  auth_google_cs_label: 'Google 클라이언트 시크릿',
+  auth_gh_client_id_label: 'GitHub 클라이언트 ID',
+  auth_gh_client_id_hint:
+    '인가 콜백 URL이 https://{domain}/api/v1/auth/github/token으로 설정되어 있는지 확인하십시오.',
+  auth_gh_client_secret_label: 'GitHub 클라이언트 비밀키',
+  auth_keycloak_label: 'Keycloak 디스커버리 URL',
+  auth_keycloak_ci_label: '키클록 클라이언트 ID',
+  auth_keycloak_ci_hint:
+    '승인 콜백 URL이 https://{domain}/api/v1/auth/keycloak/token으로 설정되어 있는지 확인하십시오.',
+  auth_keycloak_cs_label: 'Keycloak 클라이언트 시크릿',
+  currency_settings: '통화 설정',
+  allowed_currencies: '허용되는 통화',
+  allowed_currencies_hint: '사용 가능한 법정 화폐의 수를 제한하십시오.',
+  default_account_currency: '기본 계좌 통화',
+  default_account_currency_hint: '회계 기본 통화',
+  service_fee_label: '서비스 수수료 (%)',
+  service_fee_hint: '트랜잭션당 수수료 (%)',
+  service_fee_max_label: '서비스 수수료 최대 (sats)',
+  service_fee_max_hint: '(사토시)로 부과할 최대 서비스 요금',
+  fee_wallet: '수수료 지갑',
+  fee_wallet_label: '수수료 지갑 (지갑 ID)',
+  fee_wallet_hint: '자금을 보낼 지갑 ID',
+  disable_fee: '수수료 비활성화',
+  disable_fee_internal: '내부 결제에 대한 서비스 요금 비활성화',
+  disable_fee_internal_desc: '내부 라이트닝 결제에 대한 서비스 요금 비활성화',
+  ui_management: 'UI 관리',
+  ui_site_title: '사이트 제목',
+  ui_site_tagline: '사이트 태그라인',
+  ui_elements_enable: '홈페이지의 요소 활성화',
+  ui_elements_disable: '홈페이지의 요소 비활성화',
+  ui_toggle_elements_tip: "'에 의해 구동됨' 등의 홈페이지 요소 제거",
+  ui_site_description: '사이트 설명',
+  ui_site_description_hint:
+    '일반 텍스트, Markdown, 또는 원시 HTML을 사용하십시오.',
+  ui_default_wallet_name: '기본 지갑 이름',
+  lnbits_wallet: 'LNbits 지갑',
+  denomination: '액면가',
+  denomination_hint: 'FakeWallet 토큰의 이름',
+  ui_qr_code_logo: 'QR 코드 로고',
+  ui_qr_code_logo_hint: 'QR 코드의 로고 이미지 URL',
+  ui_custom_badge: '맞춤 배지',
+  ui_custom_badge_label:
+    "사용자 지정 배지 '주의하여 사용 - LNbits 지갑은 여전히 BETA 상태입니다'",
+  ui_custom_badge_color_label: '사용자 정의 배지 색상',
+  themes: '테마',
+  themes_hint: '사용자가 사용할 수 있는 테마 선택',
+  custom_logo: '맞춤 로고',
+  custom_logo_hint: '로고 이미지의 URL',
+  ad_space_title: '광고 공간 제목',
+  ad_space_title_label: '지원:',
+  ad_slots: '광고 슬롯',
+  ad_slots_hint:
+    '광고 URL 및 이미지 파일 경로를 CSV 형식으로, 확장자는 준수할 수 있습니다.',
+  ad_slots_label: 'url;img_light_url;img_dark_url, url...',
+  ads_enabled: '광고 활성화됨',
+  ads_disabled: '광고 비활성화됨',
+  user_management: '사용자 관리',
+  admin_users: '관리자 사용자',
+  admin_users_hint: '관리자 권한이 있는 사용자',
+  admin_users_label: '사용자 ID',
+  allowed_users: '허용된 사용자',
+  allowed_users_hint: 'LNbits는 이 사용자들만 사용할 수 있습니다.',
+  allowed_users_label: '사용자 ID',
+  allow_creation_user: '새 사용자 생성 허용',
+  allow_creation_user_desc: '색인 페이지에서 새 사용자 생성 허용',
+  components: '구성 요소',
+  long_running_endpoints: '최상위 5개의 장시간 실행 엔드포인트',
+  http_request_methods: 'HTTP 요청 메서드',
+  http_response_codes: 'HTTP 응답 코드',
+  request_details: '요청 세부사항',
+  http_request_details: 'HTTP 요청 세부사항'
 }
